
## CATO-CLI - mutation.sandbox.deleteReport:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.sandbox.deleteReport) for documentation on this operation.

### Usage for mutation.sandbox.deleteReport:

`catocli mutation sandbox deleteReport -h`

`catocli mutation sandbox deleteReport <json>`

`catocli mutation sandbox deleteReport "$(cat < mutation.sandbox.deleteReport.json)"`

`catocli mutation sandbox deleteReport '{"deleteReportInput":{"fileHash":"string"}}'`

`catocli mutation sandbox deleteReport -p '{
    "deleteReportInput": {
        "fileHash": "string"
    }
}'`


#### Operation Arguments for mutation.sandbox.deleteReport ####

`accountId` [ID] - (required) N/A    
`deleteReportInput` [DeleteReportInput] - (required) N/A    
